@@ -1,11 +1,12 @@
 /* common actions that affect different parts of the UI (webviews, tabstrip, etc) */
 
+var webviews = require('webviews.js')
 var urlParser = require('util/urlParser.js')
 var focusMode = require('focusMode.js')
 
 /* loads a page in a webview */
 
-window.navigate = function (tabId, newURL) {
+function navigate (tabId, newURL) {
   newURL = urlParser.parse(newURL)
 
   tabs.update(tabId, {
@@ -169,6 +170,24 @@ function switchToTab (id, options) {
   })
 }
 
+webviews.bindEvent('new-window', function (webview, tabId, e, url, frameName, disposition) {
+  var currentIndex = tabs.getIndex(tabs.getSelected())
+
+  var newTab = tabs.add({
+    url: url,
+    private: tabs.get(tabId).private // inherit private status from the current tab
+  }, currentIndex + 1)
+
+  addTab(newTab, {
+    enterEditMode: false,
+    openInBackground: disposition === 'background-tab' // possibly open in background based on disposition
+  })
+}, {preventDefault: true})
+
+webviews.bindIPC('close-window', function (webview, tabId, args) {
+  closeTab(tabId)
+})
+
 module.exports = {
   navigate,
   addTask,
