@@ -1,10 +1,9 @@
 var searchbarPlugins = require('searchbar/searchbarPlugins.js')
-var searchbarUtils = require('searchbar/searchbarUtils.js')
 var urlParser = require('util/urlParser.js')
 const hosts = require('util/hosts.js')
 
-function showHostsSuggestions (text, input, event, container) {
-  empty(container)
+function showHostsSuggestions (text, input, event) {
+  searchbarPlugins.reset('hostsSuggestions')
 
   var results = hosts.filter(function (host) {
     // only match start of host string
@@ -12,20 +11,22 @@ function showHostsSuggestions (text, input, event, container) {
   })
 
   results.slice(0, 4).forEach(function (result) {
-    var item = searchbarUtils.createItem({
+    searchbarPlugins.addResult('hostsSuggestions', {
       title: result,
       secondaryText: l('hostsFileEntry'),
       url: 'http://' + result
     })
-
-    container.appendChild(item)
   })
 }
 
-searchbarPlugins.register('hostsSuggestions', {
-  index: 1,
-  trigger: function (text) {
-    return (hosts.length && typeof text === 'string' && text.length > 2)
-  },
-  showResults: showHostsSuggestions
-})
+function initialize () {
+  searchbarPlugins.register('hostsSuggestions', {
+    index: 1,
+    trigger: function (text) {
+      return (hosts.length && typeof text === 'string' && text.length > 2)
+    },
+    showResults: showHostsSuggestions
+  })
+}
+
+module.exports = {initialize}
