@@ -1,5 +1,8 @@
 /* implements userscript support */
 
+var webviews = require('webviews.js')
+var settings = require('util/settings/settings.js')
+
 var userScriptsEnabled = false
 var domainScriptMap = {}
 
@@ -45,13 +48,12 @@ this listener has to be attached immediately so that we can capture events for
 webviews that are created at startup
 */
 
-webviews.bindEvent('dom-ready', function (e) {
+webviews.bindEvent('dom-ready', function (webview, tabId, e) {
   if (!userScriptsEnabled) {
     return
   }
-  var tab = webviews.getTabFromContents(this)
 
-  webviews.callAsync(tab, 'getURL', null, (err, src) => {
+  webviews.callAsync(tabId, 'getURL', null, (err, src) => {
     if (err) {
       return
     }
